==> apache-iotdb-0.11.4-source-release.zip: apache-iotdb-0.11.4/server/src/main/java/org/apache/iotdb/db/query/externalsort/LineMerger.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iotdb.db.query.externalsort;

import java.io.IOException;
import java.util.List;
import org.apache.iotdb.db.query.control.QueryResourceManager;
import org.apache.iotdb.db.query.externalsort.serialize.IExternalSortFileDeserializer;
import org.apache.iotdb.db.query.externalsort.serialize.IExternalSortFileSerializer;
import org.apache.iotdb.db.query.externalsort.serialize.impl.FixLengthIExternalSortFileDeserializer;
import org.apache.iotdb.db.query.externalsort.serialize.impl.FixLengthTimeValuePairSerializer;
import org.apache.iotdb.db.query.reader.universal.PriorityMergeReader;
import org.apache.iotdb.tsfile.read.reader.IPointReader;


public class LineMerger {

  private String tmpFilePath;
  private long queryId;

  public LineMerger(long queryId, String tmpFilePath) {
    this.tmpFilePath = tmpFilePath;
    this.queryId = queryId;
  }

  public IPointReader merge(List<IPointReader> prioritySeriesReaders)
      throws IOException {
    IExternalSortFileSerializer serializer = new FixLengthTimeValuePairSerializer(tmpFilePath);
    PriorityMergeReader reader = new PriorityMergeReader(prioritySeriesReaders, 1);
    while (reader.hasNextTimeValuePair()) {
      serializer.write(reader.nextTimeValuePair());
    }
    reader.close();
    serializer.close();
    IExternalSortFileDeserializer deserializer = new FixLengthIExternalSortFileDeserializer(
        tmpFilePath);
    QueryResourceManager.getInstance().registerTempExternalSortFile(queryId, deserializer);
    return deserializer;
  }
}

==> apache-iotdb-0.13.4-source-release.zip: apache-iotdb-0.13.4/server/src/main/java/org/apache/iotdb/db/query/externalsort/LineMerger.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iotdb.db.query.externalsort;

import org.apache.iotdb.db.query.control.QueryResourceManager;
import org.apache.iotdb.db.query.externalsort.serialize.IExternalSortFileDeserializer;
import org.apache.iotdb.db.query.externalsort.serialize.IExternalSortFileSerializer;
import org.apache.iotdb.db.query.externalsort.serialize.impl.FixLengthIExternalSortFileDeserializer;
import org.apache.iotdb.db.query.externalsort.serialize.impl.FixLengthTimeValuePairSerializer;
import org.apache.iotdb.db.query.reader.universal.PriorityMergeReader;
import org.apache.iotdb.tsfile.read.reader.IPointReader;

import java.io.IOException;
import java.util.List;

public class LineMerger {

  private String tmpFilePath;
  private long queryId;

  public LineMerger(long queryId, String tmpFilePath) {
    this.tmpFilePath = tmpFilePath;
    this.queryId = queryId;
  }

  public IPointReader merge(List<IPointReader> prioritySeriesReaders) throws IOException {
    IExternalSortFileSerializer serializer = new FixLengthTimeValuePairSerializer(tmpFilePath);
    PriorityMergeReader reader = new PriorityMergeReader(prioritySeriesReaders, 1);
    while (reader.hasNextTimeValuePair()) {
      serializer.write(reader.nextTimeValuePair());
    }
    reader.close();
    serializer.close();
    IExternalSortFileDeserializer deserializer =
        new FixLengthIExternalSortFileDeserializer(tmpFilePath);
    QueryResourceManager.getInstance().registerTempExternalSortFile(queryId, deserializer);
    return deserializer;
  }
}
